//
// Created by zoe on 3/28/23.
//

/**
 * @file Definitions.h
 * @brief General variable definitions for clients
 * @details This file contains general variable definitions for clients
 */

#ifndef CLIENT_ESP_CAM_DEFINITIONS_H
#define CLIENT_ESP_CAM_DEFINITIONS_H

#include <Arduino.h>

// Print additional SDI12 Information
constexpr bool SDI12_DEBUG = true;

// SDA and SCL pins for I2C
constexpr int SDA_PIN = 13;
constexpr int SCL_PIN = 12;

// Pin definitions for I2C (SHT85)
constexpr int SHT85_SDA = SDA_PIN;
constexpr int SHT85_SCL = SCL_PIN;

// Pin definitions for CAMERA_MODEL_AI_THINKER
constexpr int PWDN_GPIO_NUM = 32;
constexpr int RESET_GPIO_NUM = -1;
constexpr int XCLK_GPIO_NUM = 0;
constexpr int SIOD_GPIO_NUM = 26;
constexpr int SIOC_GPIO_NUM = 27;
constexpr int Y9_GPIO_NUM = 35;
constexpr int Y8_GPIO_NUM = 34;
constexpr int Y7_GPIO_NUM = 39;
constexpr int Y6_GPIO_NUM = 36;
constexpr int Y5_GPIO_NUM = 21;
constexpr int Y4_GPIO_NUM = 19;
constexpr int Y3_GPIO_NUM = 18;
constexpr int Y2_GPIO_NUM = 5;
constexpr int VSYNC_GPIO_NUM = 25;
constexpr int HREF_GPIO_NUM = 23;
constexpr int PCLK_GPIO_NUM = 22;

// ESP_CAM
constexpr uint8_t ESPCAM_ENABLE_PIN = 0;

// LED control
constexpr int LEDpin = 4;

// UNUSED IN ESP_CAM
constexpr int DR26_SDA = 0;
constexpr int DR26_SCL = 0;

constexpr int INA219_SDA = 0;
constexpr int INA219_SCL = 0;

constexpr int LC709203F_SDA = 0;
constexpr int LC709203F_SCL = 0;

constexpr int TEROS10_SDA = 0;
constexpr int TEROS10_SCL = 0;

// Line to pull high or low to power on or off RS485 sensors
static constexpr uint8_t RS485_ENABLE_5V_PIN = 0;
static constexpr uint8_t RS485_ENABLE_12V_PIN = 0;

// Enable Pin for RS485 communication integrated circuit
static constexpr uint8_t MAX485_ENABLE = 0;

//  Line to pull high or low to receive or send data from RS485
static constexpr uint8_t RE_DE_PIN = 0;

static constexpr uint8_t RX_PIN = 0;
static constexpr uint8_t TX_PIN = 0;

constexpr uint8_t SDI12_ENABLE_PIN = 0;
constexpr uint8_t SDI12_DATA_PIN = 0;

// HARDCODED Host
constexpr bool USE_HARDCODED_HOST_MAC = true;
// 70:B8:F6:06:C7:24
// mock for mountain 0C:B8:15:81:21:5C
// constexpr uint8_t HARDCODED_HOST_MAC[6] = {0x0C, 0xB8, 0x15, 0x81, 0x21, 0x5C};
constexpr uint8_t HARDCODED_HOST_MAC[6] = {0x70, 0xB8, 0xF6, 0x05, 0x2C, 0x60};

// PWR Enable sleep duration
constexpr int PWR_ENABLE_SLEEP_DURATION_MS = 50;

// unused
constexpr int STEPUP_PIN = 0;

#endif // CLIENT_ESP_CAM_DEFINITIONS_H
